@@ -6,7 +6,6 @@
 #' values via generators.
 #'
 #' @examples
-#' \dontrun{
 #' # U Island example region
 #' coordinates <- data.frame(x = rep(seq(177.01, 177.05, 0.01), 5),
 #'                           y = rep(seq(-18.01, -18.05, -0.01), each = 5))
@@ -48,11 +47,12 @@
 #' dir(tempdir(), "*.txt") # plus generation log
 #' results_manager$summary_metric_data
 #' results_manager$summary_matrix_list
-#' }
 #'
 #' @importFrom foreach foreach
 #' @importFrom foreach %dopar%
 #' @importFrom R6 R6Class
+#' @importFrom doParallel registerDoParallel
+#' @importFrom doParallel stopImplicitCluster
 #' @include GenericManager.R
 #' @export ResultsManager
 
@@ -142,7 +142,7 @@ ResultsManager <- R6Class("ResultsManager",
       }
 
       # Generate summary metrics in parallel
-      doParallel::registerDoParallel(cores = self$parallel_cores)
+      registerDoParallel(cores = self$parallel_cores)
       self <- self # pass object to parallel
       generation_log <- foreach(i = 1:nrow(self$sample_data),
                                 .packages = c("raster"),
@@ -215,7 +215,7 @@ ResultsManager <- R6Class("ResultsManager",
         return(self$calculate_summaries(simulation_results, i))
 
       }
-      doParallel::stopImplicitCluster()
+      stopImplicitCluster()
 
       # Merge summary metric data and matrix list
       self$summary_metric_data <- data.frame(index = 1:nrow(self$sample_data),
