@@ -21,7 +21,7 @@
 #'     \item{\code{years_per_step}}{Number of years per time step (default is 1).}
 #'     \item{\code{populations}}{Number of populations.}
 #'     \item{\code{coordinates}}{Data frame (or matrix) of X-Y population coordinates.}
-#'     \item{\code{stages}}{Number of lifecycle stages.}
+#'     \item{\code{stages}}{Number of life cycle stages.}
 #'     \item{\code{initial_abundance}}{Array (or matrix) of initial abundances (at each stage in rows) for each population (in columns).}
 #'     \item{\code{stage_matrix}}{Matrix of transition (fecundity & survival) rates between stages at each time step (Leslie/Lefkovitch matrix).}
 #'     \item{\code{fecundity_mask}}{Matrix of 0-1 to indicate which (proportions) of transition rates refer to fecundity.}
@@ -96,6 +96,7 @@
 #'     \item{\code{dispersal_source_n_k}}{Dispersal proportion (p) density dependence via source population abundance divided by carrying capacity (n/k), where p is reduced via a linear slope (defined by two list items) from n/k <= \emph{cutoff} (p = 0) to n/k >= \emph{threshold} (aliases: \emph{dispersal_n_k_cutoff} & \emph{dispersal_n_k_threshold}).}
 #'     \item{\code{dispersal_target_k}}{Dispersal rate (r) density dependence via target population carrying capacity (k), where r is reduced via a linear slope (through the origin) when k <= \emph{threshold} (alias: \emph{dispersal_k_threshold}).}
 #'     \item{\code{dispersal_target_n}}{Dispersal rate (r) density dependence via target population abundance (n), where r is reduced via a linear slope (defined by two list items) from n >= \emph{threshold} to n <= \emph{cutoff} (r = 0) or visa-versa (aliases: \emph{dispersal_n_threshold} & \emph{dispersal_n_cutoff}).}
+#'     \item{\code{dispersal_target_n_k}}{Dispersal rate (r) density dependence via target population abundance divided by carrying capacity (n/k), where r is reduced via a linear slope (defined by two list items) from n/k >= \emph{threshold} to n/k <= \emph{cutoff} (r = 0) or visa-versa.}
 #'     \item{\code{abundance_threshold}}{Abundance threshold (that needs to be exceeded) for each population to persist.}
 #'     \item{\code{simulation_order}}{A vector of simulation process names in configured order of execution (default is "transition", "translocation", "harvest" (plus harvested results), "mortality", "dispersal", "results" (except harvested).}
 #'     \item{\code{additional transformation functions}}{Additional user-defined abundance transformation functions (optionally nested in lists with additional attributes) are utilised when listed in \emph{simulation_order} (function as per translocation).}
@@ -294,9 +295,13 @@ population_simulator <- function(inputs) {
   if (is.null(dispersal_target_n)) { # try aliases
     dispersal_target_n <- list(threshold = inputs$dispersal_n_threshold, cutoff = inputs$dispersal_n_cutoff)
   }
+  dispersal_target_n_k <- inputs$dispersal_target_n_k
+  if (is.null(dispersal_target_n_k)) { # try aliases
+    dispersal_target_n_k <- list(threshold = inputs$dispersal_target_n_k_threshold, cutoff = inputs$dispersal_target_n_k_cutoff)
+  }
   dispersal_function <- population_dispersal(replicates, time_steps, years_per_step, populations, demographic_stochasticity,
                                              density_stages, inputs$dispersal, dispersal_stages, dispersal_source_n_k,
-                                             dispersal_target_k, dispersal_target_n, simulator)
+                                             dispersal_target_k, dispersal_target_n, dispersal_target_n_k, simulator)
 
   # Abundance threshold
   abundance_threshold <- inputs$abundance_threshold
