@@ -95,7 +95,7 @@ test_that("file template reading raster", {
   raster_occupancy_mask <- raster::stack(replicate(10, raster::raster(vals = region$region_raster[],
                                                                       nrows = 4, ncol = 4,
                                                                       xmn = 0, xmx = 4000, ymn = 0, ymx = 4000,
-                                                                      crs = "+proj=utm +ellps=GRS80 +datum=WGS84")))
+                                                                      crs = "+proj=eqc +lat_ts=0 +lat_0=0 +lon_0=0 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs")))
   raster_occupancy_mask[][region$region_indices, ] <- occupancy_mask[raster_occupancy_mask[][region$region_indices, 1], ]
   generator <- Generator$new(description = "Test generator", decimals = 4,
                              region = Region$new(coordinates = coordinates, use_raster = TRUE))
